"""
The :mod:`skmine.preprocessing` module includes utilities and transformers
to make the data ingestion easier
"""

from .mdlp_discretizer import MDLPDiscretizer  # noqa
